```

# 目录结构


```bash
├─ public                     # 静态资源
│   ├─ favicon.ico            # favicon图标
│   └─ index.html             # html模板
├─ src                        # 项目源代码
│   ├─ services               # 所有请求
│   ├─ assets                 # 图片 字体等静态资源
│   ├─ components             # 全局公用组件
│   ├─ layout                 # 页面的全局layout，在routes.ts中使用
│   ├─ typings                # ts的类型声明放在这里面
│   ├─ models                 # Dva 全局状态管理模块
│   ├─ styles                 # 全局样式
│   ├─ utils                  # 全局公用方法
|   |  └─ api.ts              # 所有的网络请求都走这个方法
│   ├─ pages                  # 所有页面，页面文件夹的首字母必须大写
|   |- locales                # 国际化文件夹, 详见文档 https://umijs.org/zh-CN/plugins/plugin-locale 
|   |   |- en-US.ts           # 英文
|   |   └─ zh-CN.ts           # 中文
│   └─ app.ts                 # 运行时配置文件，可以在这里扩展运行时的能力，比如修改路由、修改 render 方法等。
├─ config                     # 全局配置
|   ├─ config.dev.ts          # 开发环境配置文件
|   |─ config.local.ts        # 本地环境配置文件
|   |─ config.prod.ts         # 线上环境配置文件
|   |- config.ts              # Umi 的配置文件，详见文档 https://umijs.org/config
|   |- proxy.ts               # 请求代理，如：把/api代理到某个域名, 详见文档 https://umijs.org/config#proxy
|   └─ routes.ts              # 路由配置文件，详见文档 https://umijs.org/config#routes
├─ mock                       # 项目mock 模拟数据
├─ .prettierrc                # pretty 配置文件，美化代码
├─ .prettierignore            # pretty 忽略文件
├─ tsconfig.json              # ts 配置文件   
├─ typings.d.ts               # ts 全局模块声明文件 
└── package.json              # package.json
```

# 安装

# 进入项目目录
cd 项目目录

# 安装依赖
yarn

# 启动服务
npm start

# 打包

####打包到测试环境
```
npm run build:dev  
``` 
####打包到线上环境
```
npm run build:prod  
``` 

#开发介绍

##1. 路由菜单配置
在config/routes.ts中进行路由和菜单的配置，详见文档：https://umijs.org/config#routes

##2. 新建页面
在src/pages 目录下新建页面文件，注意这里规定每个页面必须是以文件件的形式存在，并且首字符必须大写，如src/page/Home。页面文件夹包含 IconMoon.tsx、styles.less、components 文件夹,
注意：如 src/page/Home/components 文件夹中只能放当期页面独有的业务组件，切勿页面与页面之间的 components 互相引用。

##3. 新建接口
在src/services目录下新建你的接口请求，如果当前模块为user，如 src/services/user.ts方式新建。

user.ts

```typescript
 import request from '@/utils/api';
 
 /**
  * 用户登录服务
  * @param variables.username 用户名
  * @param variables.password 密码
  */
 export const userLoginApi = (variables: Api.ILoginParam) => {
   return request<Api.ILoginOutput>('/login_graphql', {
     variables,
     query: `query certificate($username: String!, $password: String!) {
       certificate(username: $username,password: $password) {
         accessToken
         idToken
         refreshToken
         expiresIn
         tokenType
         permissions
         context
       }
     }`,
   });
 };
```
接口方法写法如上所示，api请求统一使用src/utils/api.ts 方法，每个接口方法后面必须用Api结尾，以便于区分。

##4. 使用国际化
国际化统一放在  locales 目录下 en-US.ts、zh-CN.ts 分别为英文、中文。

格式为：
```typescript
export default {
  'login.title': '卖家系统',
  'login.button': '登录',
};

```

使用方法：
```typescript
import { useIntl } from 'umi';

const Test = () => {
  const intl = useIntl();
  return (
     <div>{intl.formatMessage({ id: 'login.button' })}<div>
  )
}
```

##5. dava状态管理
在src/models中创建模块，如果当前模块为user，如：src/models/user.ts. 可参考文档： https://umijs.org/zh-CN/plugins/plugin-dva

格式为：
```typescript
import { message } from 'antd';
import type { Model } from 'dva';
import { userLoginApi } from '@/services/user';

export type UserState = Partial<
  Pick<
    Api.ILoginOutput['certificate'],
    'accessToken' | 'expiresIn' | 'tokenType'
  >
>;

const userState: UserState = {};

export default <Model>{
  namespace: 'user',
  state: userState,
  // 副作用，里面可放置请求
  effects: {
    // 用户登录
    *login({ payload }, { call, put }) {
      try {
        const res: Api.ILoginOutput = yield call(userLoginApi, payload);
        yield put({ type: 'save', payload: res.certificate });
      } catch (err: any) {
        message.error(err.message);
      }
    },
    // 退出登录
    *logout(_, { call, put }) {
      yield put({ type: 'save', payload: { accessToken: '' } });
    },
  },
  reducers: {
    save(state, { payload }: any) {
      // 保存数据到 state
      return { ...state, ...payload };
    },
  },
};
```

页面上获取数据
```tsx
import { Button } form 'antd';
import { useSelector, useDispatch } from 'umi';
const Test = () => {
  const diapath = useDispatch();
  const effectType = 'user/login';
  // 执行dispath的loading
  const user = useSelector<IState, UserState>((state) => state.user);
  const loading = useSelector<IModelState, boolean>((state) => {
    return state.loading.effects?.[effectType];
  });

  const onClick = () => {
     diapath({ 
       type: effectType,
       payload: { username: 'xxx', password: 'xxx' }
    });
  }

  return (
    <div>
       Token: {user.accessToken}
       <Button onClick={onClick} loading={loading}>点击登录</Button>
    </div>
  )
}
```

##6. typescript 声明文件
在src/typings 中放入声明文件，如当前模块为user，如src/typings/Api/user.d.ts;

格式如下：
```typescript
declare namespace Api {
  interface ILoginOutput {
    certificate: {
      expiresIn: number;
      accessToken: string;
      tokenType: string;
      refreshToken: string;
    };
  }
}
```

#使用组件
详细文档，见 https://pro.ant.design/zh-CN/docs/overview/

#使用hooks
详细文档，见 https://ahooks.js.org/

#代码提交规范
 1. 基于master创建自己的开发分支；
 2. 提交代码只允许提交到自己的开发分支，不允许直接push到master；
 3. 合并到master需要到到github 上创建pull request, 并且选择评审人，经评审通过以后，由评审人点击合并，合并到master。


